<?php
/**
 * Theme functions file
 *
 * Contains all of the Theme's setup functions, custom functions,
 * custom hooks and Theme settings.
 */

if ( ! function_exists( 'venissa_theme_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 */
	function venissa_theme_setup() {

		// Make the theme available for translation.
		load_theme_textdomain( 'venissa', trailingslashit( get_template_directory() ) . 'languages' );

		// Add custom stylesheet file to the TinyMCE visual editor.
		add_theme_support( 'editor-styles' );
		add_editor_style( array( venissa_fonts_url() ) );

		// Add RSS feed links to <head> for posts and comments.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		// Enable support for Post Thumbnails.
		add_theme_support( 'post-thumbnails' );

		// Declare image sizes.
		add_image_size( 'venissa-post', 825, 500, true );
		add_image_size( 'venissa-post-small', 510, 340, true );
		add_image_size( 'venissa-post-large', 1110, 600, true );
		add_image_size( 'venissa-featured', 772, 675, true );
		add_image_size( 'venissa-featured-two', 555, 600, true );

		// Register custom navigation menu.
		register_nav_menus(
			array(
				'primary' => esc_html__( 'Primary Navigation', 'venissa' ),
				'mobile'  => esc_html__( 'Mobile Navigation', 'venissa' ),
				'footer'  => esc_html__( 'Footer Navigation', 'venissa' ),
				'social'  => esc_html__( 'Social Navigation', 'venissa' )
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Setup the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'venissa_custom_background_args', array(
			'default-color' => 'ffffff'
		) ) );

		// Enable support for Custom Logo
		add_theme_support( 'custom-logo', array(
			'height'      => 26,
			'width'       => 200,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		// This theme uses its own gallery styles.
		add_filter( 'use_default_gallery_style', '__return_false' );

		// Indicate widget sidebars can use selective refresh in the Customizer.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Enable layouts extensions.
		add_theme_support( 'theme-layouts',
			array(
				'full-width'        => esc_html__( 'Full width', 'venissa' ),
				'full-width-narrow' => esc_html__( 'Full width narrow', 'venissa' ),
				'right-sidebar'     => esc_html__( 'Right sidebar', 'venissa' ),
				'left-sidebar'      => esc_html__( 'Left sidebar', 'venissa' )
			),
			array( 'customize' => false, 'default' => 'right-sidebar' )
		);

		// Adding support for core block visual styles.
	add_theme_support( 'wp-block-styles' );

	// Add support for full and wide align images.
	add_theme_support( 'align-wide' );

	// Add support for custom color scheme.
	add_theme_support( 'editor-color-palette' );

	// Add support for custom font sizes.
	add_theme_support( 'editor-font-sizes', array(
		array(
			'name' => esc_html__( 'Small', 'venissa' ),
			'size' => 14,
			'slug' => 'small'
		),
		array(
			'name' => esc_html__( 'Normal', 'venissa' ),
			'size' => 16,
			'slug' => 'normal'
		),
		array(
			'name' => esc_html__( 'Medium', 'venissa' ),
			'size' => 24,
			'slug' => 'medium'
		),
		array(
			'name' => esc_html__( 'Large', 'venissa' ),
			'size' => 36,
			'slug' => 'large'
		),
		array(
			'name' => esc_html__( 'Huge', 'venissa' ),
			'size' => 48,
			'slug' => 'huge'
		)
	) );

	// Add support for responsive embeds.
	add_theme_support( 'responsive-embeds' );

	}
endif; // venissa_theme_setup
add_action( 'after_setup_theme', 'venissa_theme_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function venissa_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'venissa_content_width', 825 );
}
add_action( 'after_setup_theme', 'venissa_content_width', 0 );

/**
 * Editor style for Gutenberg
 */
function venissa_editor_style() {
	wp_enqueue_style( 'venissa-editor-style', trailingslashit( get_template_directory_uri() ) . 'assets/css/editor-style.css' );
}
add_action( 'enqueue_block_editor_assets', 'venissa_editor_style' );

/**
 * Sets custom content width when current layout is full-width
 */
if ( ! function_exists( 'venissa_fullwidth_content_width' ) ) :

	function venissa_fullwidth_content_width() {
		global $content_width;

		if ( in_array( get_theme_mod( 'theme_layout' ), array( 'full-width' ) ) ) {
			$content_width = 1110;
		}
	}

endif;
add_action( 'template_redirect', 'venissa_fullwidth_content_width' );

/**
 * Registers custom widgets.
 *
 * @link  http://codex.wordpress.org/Function_Reference/register_widget
 */
function venissa_widgets_init() {

	// Register recent posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-posts.php';
	register_widget( 'Venissa_Posts_Widget' );

	// Register social widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-social.php';
	register_widget( 'Venissa_Social_Widget' );

	// Register facebook widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-facebook.php';
	register_widget( 'Venissa_Facebook_Widget' );

}
add_action( 'widgets_init', 'venissa_widgets_init' );

/**
 * Registers widget areas and custom widgets.
 *
 * @link  http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function venissa_sidebars_init() {

	register_sidebar(
		array(
			'name'          => esc_html__( 'Primary', 'venissa' ),
			'id'            => 'primary',
			'description'   => esc_html__( 'Main sidebar that appears on the right.', 'venissa' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title module-title">',
			'after_title'   => '</h3>',
		)
	);

	// Get the footer widget column from Customizer.
	$widget_columns = get_theme_mod( 'venissa_footer_widget_column', '3' );
	for ( $i = 1; $i <= $widget_columns; $i++ ) {
		register_sidebar(
			array(
				'name'          => sprintf( esc_html__( 'Footer %s', 'venissa' ), $i ),
				'id'            => 'footer-' . $i,
				'description'   => esc_html__( 'Sidebar that appears on the bottom of your site.', 'venissa' ),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h3 class="widget-title module-title">',
				'after_title'   => '</h3>',
			)
		);
	}

}
add_action( 'widgets_init', 'venissa_sidebars_init' );

/**
 * Register Google fonts.
 */
function venissa_fonts_url() {

	// Get the customizer data
	$body_font    = get_theme_mod( 'venissa_body_font', 'Source+Sans+Pro:400,400i,600,600i' );
	$heading_font = get_theme_mod( 'venissa_heading_font', 'Playfair+Display:400,400i' );

	// Important variable
	$fonts_url = '';
	$fonts     = array();

	if ( $body_font ) {
		$fonts[] = esc_attr( str_replace( '+', ' ', $body_font ) );
	}

	if ( $heading_font && ( $body_font != $heading_font ) ) {
		$fonts[] = esc_attr( str_replace( '+', ' ', $heading_font ) );
	}

	if ( $fonts ) {

		$query_args = array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}

/**
 * Post views count
 */
function venissa_post_views( $id ) {

	if ( is_singular() ) {

		$key   = 'post_views';
		$count = get_post_meta( $id, $key, true );

		if ( $count == '' ) {
			$count = 0;
			delete_post_meta( $id, $key );
			add_post_meta( $id, $key, '0' );
		} else {
			$count++;
			update_post_meta( $id, $key, $count );
		}
	}

}

/**
 * Custom template tags for this theme.
 */
require trailingslashit( get_template_directory() ) . 'inc/template-tags.php';

/**
 * Enqueue scripts and styles.
 */
require trailingslashit( get_template_directory() ) . 'inc/scripts.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require trailingslashit( get_template_directory() ) . 'inc/extras.php';

/**
 * Require and recommended plugins list.
 */
require trailingslashit( get_template_directory() ) . 'inc/plugins.php';

/**
 * Customizer.
 */
require trailingslashit( get_template_directory() ) . 'inc/customizer/customizer.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/sanitize.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/style.php';

/**
 * We use some part of Hybrid Core to extends our themes.
 *
 * @link  http://themehybrid.com/hybrid-core Hybrid Core site.
 */
require trailingslashit( get_template_directory() ) . 'inc/extensions/layouts.php';

/**
 * Demo importer
 */
require trailingslashit( get_template_directory() ) . 'inc/demo/demo-importer.php';

/**
 * Custom category meta.
 */
require trailingslashit( get_template_directory() ) . 'inc/category/category.php';

/**
 * Auto update script.
 */
require trailingslashit( get_template_directory() ) . 'inc/update.php';

/**
 * MailOptin integration
 */
require trailingslashit( get_template_directory() ) . 'inc/extensions/mailoptin.php';
